module(..., package.seeall)

-- Load libraries
require("modelfunctions")
fs = require("acf.fs")
format = require("acf.format")

-- Set variables
local processname = "clamd"
local packagename = "clamav"
local filelist = {"/etc/clamav/clamd.conf", "/etc/clamav/freshclam.conf"}

local path = "PATH=/usr/local/bin:/usr/bin:/bin:/usr/local/sbin:/usr/sbin:/sbin "

-- ################################################################################
-- LOCAL FUNCTIONS

-- ################################################################################
-- PUBLIC FUNCTIONS

function get_startstop(self, clientdata)
	return modelfunctions.get_startstop(processname)	
end

function startstop_service(self, startstop, action)
	return modelfunctions.startstop_service(startstop, action)
end

function getstatus()
	return modelfunctions.getstatus(processname, packagename, "ClamAV Status")
end

function getstatusdetails()
	return cfe({ type="longtext", value="", label="ClamAV Status Details" })
end

function getfilelist()
	local listed_files = {}

	for i,name in ipairs(filelist) do
		local filedetails = fs.stat(name) or {}
		table.insert ( listed_files , {filename=name, mtime=filedetails.mtime or "---", filesize=filedetails.size or "0"} )
	end

	table.sort(listed_files, function (a,b) return (a.filename < b.filename) end )

	return cfe({ type="list", value=listed_files, label="ClamAV File List" })
end

function getfiledetails(self, clientdata)
	return modelfunctions.getfiledetails(clientdata.filename, filelist)
end

function updatefiledetails(self, filedetails)
	return modelfunctions.setfiledetails(self, filedetails, filelist)
end

function getlogfile ()
	local files = {}
	local logfilepath = format.parse_configfile(fs.read_file(filelist[1]) or "").LogFile
	if not logfilepath then
		files[#files+1] = {path = "/var/log/messages", grep = "clamd"}
	else
		files[#files+1] = {path=logfilepath}
	end
	logfilepath = format.parse_configfile(fs.read_file(filelist[2]) or "").UpdateLogFile
	if not logfilepath then
		files[#files+1] = {path = "/var/log/messages", grep = "freshclam"}
	else
		files[#files+1] = {path=logfilepath}
	end
	return cfe({ value=files, label="ClamAV logfiles" })
end
